Documentation
¶
Index ¶
- func ParseRepo(slug string) (owner, repo string, err error)
- func ValidateToken(token string) (string, error)
- type Client
- func (c *Client) CheckPathExists(ctx context.Context, owner, repo, path string) bool
- func (c *Client) CountOpenPRs(ctx context.Context, owner, repo string) (int, error)
- func (c *Client) GetCommitActivity(ctx context.Context, owner, repo string) ([]int, error)
- func (c *Client) GetCommunityProfile(ctx context.Context, owner, repo string) (*github.CommunityHealthFiles, error)
- func (c *Client) GetContributorStats(ctx context.Context, owner, repo string) ([]*github.ContributorStats, error)
- func (c *Client) GetFileContents(ctx context.Context, owner, repo, path string) (string, error)
- func (c *Client) GetLanguages(ctx context.Context, owner, repo string) (map[string]int, error)
- func (c *Client) GetRecentCommitTimes(ctx context.Context, owner, repo string, pages int) ([]time.Time, error)
- func (c *Client) GetRecentStargazers(ctx context.Context, owner, repo string, totalStars int) ([]*github.Stargazer, error)
- func (c *Client) GetRepo(ctx context.Context, owner, repo string) (*github.Repository, error)
- func (c *Client) GetUserLocation(ctx context.Context, login string) (string, error)
- func (c *Client) ListActiveForks(ctx context.Context, owner, repo string) ([]*github.Repository, error)
- func (c *Client) ListContributors(ctx context.Context, owner, repo string) ([]*github.Contributor, error)
- func (c *Client) ListLabels(ctx context.Context, owner, repo string) ([]string, error)
- func (c *Client) ListOpenIssues(ctx context.Context, owner, repo string) ([]*github.Issue, error)
- func (c *Client) ListRecentClosedIssues(ctx context.Context, owner, repo string) ([]*github.Issue, error)
- func (c *Client) ListRecentPRs(ctx context.Context, owner, repo string) ([]*github.PullRequest, error)
- func (c *Client) ListReleases(ctx context.Context, owner, repo string) ([]*github.RepositoryRelease, error)
- func (c *Client) ListStargazers(ctx context.Context, owner, repo string, maxPages int) ([]*github.Stargazer, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ValidateToken ¶
ValidateToken checks if a token is valid and returns the authenticated username.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (*Client) CheckPathExists ¶
CheckPathExists returns true if the given path exists in the repository (file or directory).
func (*Client) CountOpenPRs ¶
func (*Client) GetCommitActivity ¶
func (*Client) GetCommunityProfile ¶
func (*Client) GetContributorStats ¶
func (*Client) GetFileContents ¶
func (*Client) GetLanguages ¶
func (*Client) GetRecentCommitTimes ¶
func (*Client) GetRecentStargazers ¶
func (c *Client) GetRecentStargazers(ctx context.Context, owner, repo string, totalStars int) ([]*github.Stargazer, error)
GetRecentStargazers fetches the most recently added stargazers by requesting the last page of the stargazer list, given the total star count.
func (*Client) GetUserLocation ¶
func (*Client) ListActiveForks ¶
func (*Client) ListContributors ¶
func (*Client) ListLabels ¶
func (*Client) ListOpenIssues ¶
func (*Client) ListRecentClosedIssues ¶
func (*Client) ListRecentPRs ¶
func (*Client) ListReleases ¶
Click to show internal directories.
Click to hide internal directories.